==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/chalk/ui/kis_selection_options.cc <==
/*
 *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <tqwidget.h>
#include <tqradiobutton.h>
#include <tqcombobox.h>
#include <kcolorbtn.h>
#include <tqlayout.h>

#include "kis_canvas_controller.h"
#include "kis_canvas_subject.h"
#include "wdgselectionoptions.h"
#include "kis_selection_options.h"
#include "kis_types.h"
#include "kis_layer.h"
#include "kis_image.h"
#include "kis_selection.h"
#include "kis_paint_device.h"

KisSelectionOptions::KisSelectionOptions(TQWidget *parent, KisCanvasSubject * subject)
    : super(parent),
      m_subject(subject)
{
    m_page = new WdgSelectionOptions(this);
    Q_CHECK_PTR(m_page);

    TQVBoxLayout * l = new TQVBoxLayout(this);
    l->addWidget(m_page);

    connect(m_page->cmbAction, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(actionChanged(int)));
}

KisSelectionOptions::~KisSelectionOptions()
{
}

int KisSelectionOptions::action()
{
    return m_page->cmbAction->currentItem();
}

void KisSelectionOptions::slotActivated()
{
    
    if (!m_subject) return;
    KisImageSP img = m_subject->currentImg();
    if (!img) return;
    KisPaintDeviceSP dev = img->activeDevice();
    if (!dev) return;

    if (dev->hasSelection()) {
    }
}

#include "kis_selection_options.moc"

==> koffice-trinity_14.0.9.orig.tar.xz: koffice-trinity-14.0.9/chalk/ui/kis_selection_options.cc <==
/*
 *  Copyright (c) 2005 Boudewijn Rempt <boud@valdyas.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include <tqwidget.h>
#include <tqradiobutton.h>
#include <tqcombobox.h>
#include <kcolorbtn.h>
#include <tqlayout.h>

#include "kis_canvas_controller.h"
#include "kis_canvas_subject.h"
#include "wdgselectionoptions.h"
#include "kis_selection_options.h"
#include "kis_types.h"
#include "kis_layer.h"
#include "kis_image.h"
#include "kis_selection.h"
#include "kis_paint_device.h"

KisSelectionOptions::KisSelectionOptions(TQWidget *parent, KisCanvasSubject * subject)
    : super(parent),
      m_subject(subject)
{
    m_page = new WdgSelectionOptions(this);
    TQ_CHECK_PTR(m_page);

    TQVBoxLayout * l = new TQVBoxLayout(this);
    l->addWidget(m_page);

    connect(m_page->cmbAction, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(actionChanged(int)));
}

KisSelectionOptions::~KisSelectionOptions()
{
}

int KisSelectionOptions::action()
{
    return m_page->cmbAction->currentItem();
}

void KisSelectionOptions::slotActivated()
{
    
    if (!m_subject) return;
    KisImageSP img = m_subject->currentImg();
    if (!img) return;
    KisPaintDeviceSP dev = img->activeDevice();
    if (!dev) return;

    if (dev->hasSelection()) {
    }
}

#include "kis_selection_options.moc"
